@@ -146,7 +146,7 @@ class MemoryDBClient(BaseClient):
         """
 
     def batch_update_cluster(
-        self, *, ClusterNames: Sequence[str], ServiceUpdate: "ServiceUpdateRequestTypeDef" = ...
+        self, *, ClusterNames: Sequence[str], ServiceUpdate: ServiceUpdateRequestTypeDef = ...
     ) -> BatchUpdateClusterResponseTypeDef:
         """
         Apply the service update to a list of clusters supplied.
@@ -163,6 +163,14 @@ class MemoryDBClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/memorydb.html#MemoryDB.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_memorydb/client/#close)
+        """
+
     def copy_snapshot(
         self,
         *,
@@ -170,7 +178,7 @@ class MemoryDBClient(BaseClient):
         TargetSnapshotName: str,
         TargetBucket: str = ...,
         KmsKeyId: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CopySnapshotResponseTypeDef:
         """
         Makes a copy of an existing snapshot.
@@ -180,7 +188,7 @@ class MemoryDBClient(BaseClient):
         """
 
     def create_acl(
-        self, *, ACLName: str, UserNames: Sequence[str] = ..., Tags: Sequence["TagTypeDef"] = ...
+        self, *, ACLName: str, UserNames: Sequence[str] = ..., Tags: Sequence[TagTypeDef] = ...
     ) -> CreateACLResponseTypeDef:
         """
         Creates an Access Control List.
@@ -209,7 +217,7 @@ class MemoryDBClient(BaseClient):
         SnapshotArns: Sequence[str] = ...,
         SnapshotName: str = ...,
         SnapshotRetentionLimit: int = ...,
-        Tags: Sequence["TagTypeDef"] = ...,
+        Tags: Sequence[TagTypeDef] = ...,
         SnapshotWindow: str = ...,
         EngineVersion: str = ...,
         AutoMinorVersionUpgrade: bool = ...
@@ -227,7 +235,7 @@ class MemoryDBClient(BaseClient):
         ParameterGroupName: str,
         Family: str,
         Description: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateParameterGroupResponseTypeDef:
         """
         Creates a new MemoryDB parameter group.
@@ -242,7 +250,7 @@ class MemoryDBClient(BaseClient):
         ClusterName: str,
         SnapshotName: str,
         KmsKeyId: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateSnapshotResponseTypeDef:
         """
         Creates a copy of an entire cluster at a specific moment in time.
@@ -257,7 +265,7 @@ class MemoryDBClient(BaseClient):
         SubnetGroupName: str,
         SubnetIds: Sequence[str],
         Description: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateSubnetGroupResponseTypeDef:
         """
         Creates a subnet group.
@@ -270,9 +278,9 @@ class MemoryDBClient(BaseClient):
         self,
         *,
         UserName: str,
-        AuthenticationMode: "AuthenticationModeTypeDef",
+        AuthenticationMode: AuthenticationModeTypeDef,
         AccessString: str,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateUserResponseTypeDef:
         """
         Creates a MemoryDB user.
@@ -462,7 +470,7 @@ class MemoryDBClient(BaseClient):
         self,
         *,
         UserName: str = ...,
-        Filters: Sequence["FilterTypeDef"] = ...,
+        Filters: Sequence[FilterTypeDef] = ...,
         MaxResults: int = ...,
         NextToken: str = ...
     ) -> DescribeUsersResponseTypeDef:
@@ -531,7 +539,7 @@ class MemoryDBClient(BaseClient):
         """
 
     def tag_resource(
-        self, *, ResourceArn: str, Tags: Sequence["TagTypeDef"]
+        self, *, ResourceArn: str, Tags: Sequence[TagTypeDef]
     ) -> TagResourceResponseTypeDef:
         """
         A tag is a key-value pair where the key and value are case-sensitive.
@@ -579,8 +587,8 @@ class MemoryDBClient(BaseClient):
         SnapshotRetentionLimit: int = ...,
         NodeType: str = ...,
         EngineVersion: str = ...,
-        ReplicaConfiguration: "ReplicaConfigurationRequestTypeDef" = ...,
-        ShardConfiguration: "ShardConfigurationRequestTypeDef" = ...,
+        ReplicaConfiguration: ReplicaConfigurationRequestTypeDef = ...,
+        ShardConfiguration: ShardConfigurationRequestTypeDef = ...,
         ACLName: str = ...
     ) -> UpdateClusterResponseTypeDef:
         """
@@ -591,7 +599,7 @@ class MemoryDBClient(BaseClient):
         """
 
     def update_parameter_group(
-        self, *, ParameterGroupName: str, ParameterNameValues: Sequence["ParameterNameValueTypeDef"]
+        self, *, ParameterGroupName: str, ParameterNameValues: Sequence[ParameterNameValueTypeDef]
     ) -> UpdateParameterGroupResponseTypeDef:
         """
         Updates the parameters of a parameter group.
@@ -614,7 +622,7 @@ class MemoryDBClient(BaseClient):
         self,
         *,
         UserName: str,
-        AuthenticationMode: "AuthenticationModeTypeDef" = ...,
+        AuthenticationMode: AuthenticationModeTypeDef = ...,
         AccessString: str = ...
     ) -> UpdateUserResponseTypeDef:
         """
